@@ -8,7 +8,8 @@ mod download;
 mod ttbytes;
     
 pub const BLOCK_SIZE: usize = 1_000_000;
-pub const URL: &str = "http://localhost:3000";
+pub const CACHE_URL: &str = "https://ca1.blindupload.org";
+pub const WWW_URL: &str = "https://www.blindupload.org";
    
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub struct IndexEntry {
@@ -26,8 +27,13 @@ fn main() -> Result<()> {
         // see if the first argument is a URL
         let url_attempt = Url::parse(&args[1]);
 
-        if args.len() == 2 && url_attempt.is_ok() {
-            download::download(url_attempt.unwrap())?;
+        if args.len() > 1 && args.len() < 4 && url_attempt.is_ok() {
+            let opt_code = if args.len() == 3 {
+                Some(args[2].as_str()) // there is a code
+            } else {
+                None // no code
+            };
+            download::download(url_attempt.unwrap(), opt_code)?;
         } else { // assume they're all filenames
             upload::upload(&args[1..])?;
         }
@@ -39,6 +45,7 @@ fn main() -> Result<()> {
 {}
 
 Usage: bup URL                      # download and decrypt
+       bup SHORT_URL TELEPHONE_CODE # download and decrypt
        bup FILENAME [FILENAMES...]  # encrypt and upload", 
             env!("CARGO_PKG_VERSION"),
             env!("CARGO_PKG_DESCRIPTION"),
